<?php
namespace base\mvc;
/**
 * ViewModel class for rendering views
 * @author Davit Araqelyan <davaraqelyan111@gmail.com>
 */
class ViewModel {
    

    /**
     * file name of layout
     * @var string 
     */
    private $_layout;

    /**
     * path of directory where located layout file
     * @var string
     */
    private $_layoutPath = null;

    /**
     * variables array asigned to view
     * @var array 
     */
    private $_variables = array();

    /**
     * default layout if isn't set layout 
     * @var string
     */
    private $_defaultLayout = null;

    /**
     *
     * @var string 
     */
    private $_controller = null;

    /**
     *
     * @var string
     */
    private $_action = null;

    /**
     * @param type $layout
     * @param array $params | key => value (variables asigned to view)
     */
    public function __construct($layout = null, $params = array()) {
        $this->_layout = $layout;
        $this->_variables = $params;
    }

    /**
     * 
     * @param string $layout
     */
    public function setLayout($layout) {
        $this->_layout = $layout;
    }

    /**
     * render current layout
     */
    public function render() {
        foreach ($this->_variables as $key => $value) {
            ${$key} = $value;
        }
        
        if (file_exists($this->_layoutPath . DS . stripslashes($this->_layout) . '.php')) {
            include $this->_layoutPath . DS . stripslashes($this->_layout) . '.php';
        } else {
            if (file_exists($this->_layoutPath . DS . stripslashes($this->_defaultLayout) . '.php')) {
                include $this->_layoutPath . DS . stripslashes($this->_defaultLayout) . '.php';
            } else {
                throw new \Exception('Missing layout file');
            }
        }
    }

    /**
     * 
     * @param array $info
     */
    public function initControllerInfo($info) {
        $this->_controller = $info['controller'];
        $this->_action = $info['action'];
    }

    public function setDefaultLayout($defaultLayout) {
        $this->_defaultLayout = $defaultLayout;
    }

    public function setLayoutPath($path) {
        $this->_layoutPath = $path;
    }

}